@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Types::Common::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Common::VERSION   = '1.999_000';
+	$Types::Common::VERSION   = '1.999_001';
 }
 
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
@@ -21,6 +21,7 @@ use Type::Library
 		Types::Standard
 		Types::Common::Numeric
 		Types::Common::String
+		Types::TypeTiny
 	) ];
 
 use Type::Params ();
@@ -77,6 +78,10 @@ All the types from L<Types::Common::Numeric> and L<Types::Common::String>.
 
 =item *
 
+All the types from L<Types::TypeTiny>.
+
+=item *
+
 The C<< -sigs >> tag from L<Type::Params>.
 
 =item *
