@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Types::Standard::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Standard::VERSION   = '1.999_000';
+	$Types::Standard::VERSION   = '1.999_001';
 }
 
 $Types::Standard::VERSION =~ tr/_//d;
@@ -645,7 +645,7 @@ $meta->$add_core_type(
 		},
 		type_default       => sub { return undef; },
 		type_default_generator => sub {
-			return $Type::Tiny::parameterize_type->type_default;
+			$_[0]->type_default || $Type::Tiny::parameterize_type->type_default ;
 		},
 	}
 );
@@ -705,6 +705,9 @@ my $_Optional = $meta->add_type(
 			return unless $param->has_coercion;
 			return $param->coercion;
 		},
+		type_default_generator => sub {
+			return $_[0]->type_default;
+		},
 	}
 );
 
@@ -726,6 +729,7 @@ $_slurpy = $meta->add_type(
 				display_name    => $self->name_generator->( $self, $param ),
 				parameters      => [ $param ],
 				constraint      => sub { $param->check( $_[0] ) },
+				type_default    => $param->type_default,
 				_build_coercion => sub {
 					my $coercion = shift;
 					$coercion->add_type_coercions( @{ $param->coercion->type_coercion_map } )
@@ -921,6 +925,7 @@ $meta->add_type(
 			push @code, '$ok }';
 			return ( undef, join( q( ), @code ) );
 		},
+		type_default => sub { return [] },
 	}
 );
 
@@ -1058,6 +1063,7 @@ $meta->add_type(
 				$coercion ? ( coercion => $coercion ) : (),
 			);
 		},
+		type_default => undef,
 	}
 );
 
@@ -1154,11 +1160,13 @@ Types::Standard - bundled set of built-in types for Type::Tiny
    );
    
    sub add_child {
-     state $check = compile( Object, Object );  # method signature
+     state $check = signature(
+       method     => Object,
+       positional => [ Object ],
+     );                                         # method signature
+     my ( $self, $child ) = $check->( @_ );     # unpack @_
      
-     my ($self, $child) = $check->(@_);         # unpack @_
      push @{ $self->children }, $child;
-     
      return $self;
    }
  }
